@@ -166,6 +166,8 @@ class Importer(BaseAction):
         return timeout
 
     def wait_for_units(self, ignore_errors=False):
+        if self.options.skip_unit_wait:
+            return
         timeout = self.check_timeout()
         # Set up the callback to be called in case of unit errors: if
         # ignore_errors is True errors are just logged, otherwise we exit the
@@ -213,7 +215,7 @@ class Importer(BaseAction):
         rels_created = self.add_relations()
 
         # Wait for the units to be up before waiting for rel stability.
-        if rels_created:
+        if rels_created and not options.skip_unit_wait:
             self.log.debug(
                 "Waiting for relation convergence %ds", options.rel_wait)
             time.sleep(options.rel_wait)
