@@ -39,6 +39,12 @@ class GoEnvironment(BaseEnvironment):
 
     def connect(self):
         self.log.debug("Connecting to environment...")
+        with open("/dev/null", 'w') as fh:
+            self._check_call(
+                self._named_env(["juju", "api-endpoints"]),
+                self.log, "Error getting env api endpoints, env bootstrapped?",
+                stderr=fh)
+
         self.client = EnvironmentClient.connect(self.name)
         self.log.debug("Connected to environment")
 
