@@ -4,16 +4,8 @@ The environment defined here is intended to be used by the Juju GUI server.
 See <https://code.launchpad.net/~juju-gui/charms/precise/juju-gui/trunk>.
 """
 
-from urllib2 import (
-    HTTPError,
-    URLError,
-)
-from .go import GoEnvironment
-from ..utils import (
-    DeploymentError,
-    get_qualified_charm_url,
-    parse_constraints,
-)
+from .go import GoEnvironment, EnvironmentClient
+from ..utils import get_qualified_charm_url, parse_constraints
 
 
 class GUIEnvironment(GoEnvironment):
@@ -42,7 +34,8 @@ class GUIEnvironment(GoEnvironment):
         client is already connected.
         """
         if self.client is None:
-            super(GUIEnvironment, self).connect()
+            self.client = EnvironmentClient(self.api_endpoint)
+            self.client.login(self._password)
 
     def close(self):
         """Close the API connection.
