@@ -119,6 +119,13 @@ class DeploymentTest(Base):
         placement = d.get_unit_placement('semper', status)
         self.assertEqual(placement.get(0), '3')
 
+        placement = d.get_unit_placement('lxc-service', status)
+        self.assertEqual(placement.get(0), 'lxc:2')
+        self.assertEqual(placement.get(1), 'lxc:3')
+        self.assertEqual(placement.get(2), 'lxc:1')
+        self.assertEqual(placement.get(3), 'lxc:1')
+        self.assertEqual(placement.get(4), 'lxc:3')
+
     def test_multiple_relations_no_weight(self):
         data = {"relations": {"wordpress": {"consumes": ["mysql"]},
                               "nginx": {"consumes": ["wordpress"]}}}
@@ -154,5 +161,19 @@ class DeploymentTest(Base):
         deployment = self.get_named_deployment("stack-placement.yaml", "stack")
         service_names = deployment.get_service_names()
         expected_service_names = [
-            'ceph', 'mysql', 'nova-compute', 'quantum', 'semper', 'verity']
+            'ceph', 'mysql', 'nova-compute', 'quantum', 'semper', 'verity', 'lxc-service']
         self.assertEqual(set(expected_service_names), set(service_names))
+
+    def test_resolve_config_handles_empty_options(self):
+        """resolve_config should handle options being "empty" lp:1361883"""
+        deployment = self.get_named_deployment("negative.cfg", "negative")
+        self.assertEqual(
+            deployment.data["services"]["foo"]["options"], {})
+        deployment.resolve_config()
+
+    def test_resolve_config_handles_none_options(self):
+        """resolve_config should handle options being "none" lp:1361883"""
+        deployment = self.get_named_deployment("negative.yaml", "negative")
+        self.assertEqual(
+            deployment.data["services"]["foo"]["options"], None)
+        deployment.resolve_config()
