@@ -8,7 +8,7 @@ from deployer.env.gui import (
 )
 
 
-@mock.patch('deployer.env.go.EnvironmentClient')
+@mock.patch('deployer.env.gui.EnvironmentClient')
 class TestGUIEnvironment(unittest.TestCase):
 
     endpoint = 'wss://api.example.com:17070'
